@@ -109,12 +109,14 @@ license 'unknown';
 author  'unknown';
 
 tests 't/*.t t/*/*.t t/*/*/*.t';
-requires 'Amon2';
-requires 'Text::Xslate';
-requires 'Text::Xslate::Bridge::TT2Like';
-requires 'Plack::Middleware::ReverseProxy';
-requires 'HTML::FillInForm::Lite';
-requires 'Time::Piece';
+requires(
+    'Amon2'                           => '<% $amon2_version %>',
+    'Text::Xslate'                    => 0,
+    'Text::Xslate::Bridge::TT2Like'   => 0,
+    'Plack::Middleware::ReverseProxy' => 0,
+    'HTML::FillInForm::Lite'          => 0,
+    'Time::Piece'                     => 0,
+);
 recursive_author_tests('xt');
 
 WriteAll;
